#!/bin/sh
#
# distccd Debian init.d script contributed by Jason Thomas.  (Debian #161136)
#
# skeleton	example file to build /etc/init.d/ scripts.
#		This file should be used to construct scripts for /etc/init.d.
#
#		Written by Miquel van Smoorenburg <miquels@cistron.nl>.
#		Modified for Debian GNU/Linux
#		by Ian Murdock <imurdock@gnu.ai.mit.edu>.
#
# Version:	@(#)skeleton  1.9.1  08-Apr-2002  miquels@cistron.nl
#

PATH=/usr/local/sbin:/usr/local/bin:/sbin:/bin:/usr/sbin:/usr/bin
DAEMON=/usr/bin/distccd
NAME=distccd
DESC="Distributed Compiler Daemon"
DAEMON_ARGS="--pid-file=/var/run/$NAME.pid --log-file=/var/log/$NAME.log --daemon"
# please change those variables by overriding them in /etc/defaults/distcc
ALLOWEDNETS="127.0.0.1"
LISTENER="127.0.0.1"

# Reads config file (will override defaults above)
[ -r /etc/default/distcc ] && . /etc/default/distcc

test -x $DAEMON || exit 0

set -e

# construct access list
ALLOW=""
for net in $ALLOWEDNETS
do
	ALLOW="$ALLOW --allow $net"
done

if test -n "$LISTENER"; then
    LISTENER="--listen $LISTENER"
fi

should_start() {
	if [ "$STARTDISTCC" != "true" ] && [ "$STARTDISTCC" != "YES" ]; then
		echo "STARTDISTCC is set to false in /etc/default/distcc"
		echo "$DAEMON not starting"
		exit 0
	fi
	# we need permission to write to the pid file
	touch /var/run/$NAME.pid
	chown distccd /var/run/$NAME.pid
}

case "$1" in
  start)
	should_start
	echo -n "Starting $DESC: $NAME"
	start-stop-daemon --start --quiet --pidfile /var/run/$NAME.pid \
	--chuid distccd \
	--exec $DAEMON -- $DAEMON_ARGS $ALLOW $LISTENER ||
	{
	    code=$?
	    echo "$0: start failed with error code $code" >&2
	    exit $code
	}
	echo "."
	;;
  stop)
	echo -n "Stopping $DESC: $NAME"
	start-stop-daemon --stop --quiet --pidfile /var/run/$NAME.pid \
		--oknodo \
		--exec $DAEMON ||
	{
	    code=$?
	    echo "$0: stop failed with error code $code" >&2
	    exit $code
	}
	echo "."
	;;
  restart|force-reload)
	#
	#	If the "reload" option is implemented, move the "force-reload"
	#	option to the "reload" entry above. If not, "force-reload" is
	#	just the same as "restart".
	#
	echo -n "Restarting $DESC: $NAME"
	start-stop-daemon --stop --quiet --pidfile /var/run/$NAME.pid \
		--oknodo \
		--exec $DAEMON
	sleep 1
	should_start
	start-stop-daemon --start --quiet --pidfile /var/run/$NAME.pid \
		--chuid distccd \
		--exec $DAEMON -- $DAEMON_ARGS $ALLOW $LISTENER ||
	{
	    code=$?
	    echo "$0: restart failed with error code $code" >&2
	    exit $code
	}
	echo "."
	;;
  *)
	N=/etc/init.d/$NAME
	echo "Usage: $N {start|stop|restart|force-reload}" >&2
	exit 1
	;;
esac

exit 0


